@@ -60,10 +60,17 @@ c
       include 'debug.h'
       include 'stat.h'
 
-c     %---------------%
-c     | MPI INTERFACE |
-c     %---------------%
-      integer           comm, myid, nprocs, rc, nloc
+c     %-------------------------------%
+c     | MPI INTERFACE                 |
+c     | ILP64 is not supported by MPI |
+c     | integer*4 must be imposed in  |
+c     | all calls involving MPI.      |
+c     |                               |
+c     | Use ierr for MPI calls.       |
+c     %-------------------------------%
+
+      integer*4         comm, myid, nprocs, rc, ierr
+
 c
 c     %-----------------------------%
 c     | Define maximum dimensions   |
@@ -90,13 +97,16 @@ c
      &                  workev(3*maxncv),
      &                  workl(3*maxncv*maxncv+6*maxncv)
 c
-c     %---------------%
-c     | Local Scalars |
-c     %---------------%
+c     %------------------------------------%
+c     | Local Scalars                      |
+c     |                                    |
+c     | Use info if ILP64 can be supported |
+c     | (call to BLAS, LAPACK, ARPACK).    |
+c     %------------------------------------%
 c
       character         bmat*1, which*2
       integer           ido, n, nx, nev, ncv, lworkl, info, j,
-     &                  ierr, nconv, maxitr, ishfts, mode
+     &                  nloc, nconv, maxitr, ishfts, mode
       Real
      &                  tol, sigmar, sigmai
       logical           first, rvec
@@ -295,7 +305,7 @@ c
          call psneupd ( comm, rvec, 'A', select, d, d(1,2), v, ldv,
      &        sigmar, sigmai, workev, bmat, nloc, which, nev, tol,
      &        resid, ncv, v, ldv, iparam, ipntr, workd, workl,
-     &        lworkl, ierr )
+     &        lworkl, info )
 c
 c        %-----------------------------------------------%
 c        | The real part of the eigenvalue is returned   |
@@ -309,7 +319,7 @@ c        | for the invariant subspace corresponding to   |
 c        | the eigenvalues in D is returned in V.        |
 c        %-----------------------------------------------%
 c
-         if ( ierr .ne. 0) then
+         if ( info .ne. 0) then
 c
 c           %------------------------------------%
 c           | Error condition:                   |
@@ -318,7 +328,7 @@ c           %------------------------------------%
 c
          	if ( myid .eq. 0 ) then
              	print *, ' '
-             	print *, ' Error with _neupd, info = ', ierr
+             	print *, ' Error with _neupd, info = ', info
              	print *, ' Check the documentation of _neupd. '
              	print *, ' '
             endif
@@ -468,7 +478,7 @@ c----------------------------------------------------------------------------
 c
 c     .. MPI Declarations ...
       include           'mpif.h'
-      integer           comm, nprocs, myid, ierr,
+      integer*4         comm, nprocs, myid, ierr,
      &                  status(MPI_STATUS_SIZE)
 c
       integer           nloc, nx, np, j, lo, next, prev
