@@ -1,4 +1,4 @@
-      program pssdrv1 
+      program pssdrv1
 c
 c     Message Passing Layer: MPI
 c
@@ -25,7 +25,7 @@ c              Ritz vectors.
 c     psnorm2  Parallel version of Level 1 BLAS that computes the norm of a vector.
 c     saxpy    Level 1 BLAS that computes y <- alpha*x+y.
 c     av       Matrix vector multiplication routine that computes A*x.
-c     tv       Matrix vector multiplication routine that computes T*x, 
+c     tv       Matrix vector multiplication routine that computes T*x,
 c              where T is a tridiagonal matrix.  It is used in routine
 c              av.
 c
@@ -56,12 +56,18 @@ c
       include 'mpif.h'
       include 'debug.h'
       include 'stat.h'
- 
-c     %---------------%
-c     | MPI INTERFACE |
-c     %---------------%
- 
-      integer           comm, myid, nprocs, rc, nloc
+
+c     %-------------------------------%
+c     | MPI INTERFACE                 |
+c     | ILP64 is not supported by MPI |
+c     | integer*4 must be imposed in  |
+c     | all calls involving MPI.      |
+c     |                               |
+c     | Use ierr for MPI calls.       |
+c     %-------------------------------%
+
+      integer*4         comm, myid, nprocs, rc, ierr
+
 c
 c     %-----------------------------%
 c     | Define leading dimensions   |
@@ -73,7 +79,7 @@ c     | MAXNCV: Maximum NCV allowed |
 c     %-----------------------------%
 c
       integer          maxnloc, maxnev, maxncv, ldv
-      parameter       (maxnloc=256, maxnev=10, maxncv=25, 
+      parameter       (maxnloc=256, maxnev=10, maxncv=25,
      &                 ldv=maxnloc )
 c
 c     %--------------%
@@ -87,15 +93,18 @@ c
       logical          select(maxncv)
       integer          iparam(11), ipntr(11)
 c
-c     %---------------%
-c     | Local Scalars |
-c     %---------------%
+c     %------------------------------------%
+c     | Local Scalars                      |
+c     |                                    |
+c     | Use info if ILP64 can be supported |
+c     | (call to BLAS, LAPACK, ARPACK).    |
+c     %------------------------------------%
 c
       character        bmat*1, which*2
-      integer          ido, n, nev, ncv, lworkl, info, ierr, j, 
+      integer          ido, n, nev, ncv, lworkl, info, nloc, j,
      &                 nx, nconv, maxitr, mode, ishfts
       logical          rvec
-      Real      
+      Real
      &                 tol, sigma
 c
 c     %----------------------------------------------%
@@ -112,13 +121,13 @@ c
       Real
      &                 zero
       parameter        (zero = 0.0)
-c  
+c
 c     %-----------------------------%
 c     | BLAS & LAPACK routines used |
 c     %-----------------------------%
 c
-      Real           
-     &                 psnorm2 
+      Real
+     &                 psnorm2
       external         psnorm2, saxpy
 c
 c     %---------------------%
@@ -152,15 +161,15 @@ c     | modify NEV, NCV, WHICH to solve problems of        |
 c     | different sizes, and to get different parts of the |
 c     | spectrum.  However, The following conditions must  |
 c     | be satisfied:                                      |
-c     |                   N <= MAXN,                       | 
+c     |                   N <= MAXN,                       |
 c     |                 NEV <= MAXNEV,                     |
-c     |             NEV + 2 <= NCV <= MAXNCV               | 
-c     %----------------------------------------------------% 
+c     |             NEV + 2 <= NCV <= MAXNCV               |
+c     %----------------------------------------------------%
 c
       nx = 10
       n = nx*nx
-      nev =  4 
-      ncv =  20 
+      nev =  4
+      ncv =  20
 c
 c     %--------------------------------------%
 c     | Set up distribution of data to nodes |
@@ -195,7 +204,7 @@ c     | iteration.                                       |
 c     %--------------------------------------------------%
 c
       lworkl = ncv*(ncv+8)
-      tol = zero 
+      tol = zero
       info = 0
       ido = 0
 c
@@ -212,10 +221,10 @@ c
       ishfts = 1
       maxitr = 300
       mode   = 1
-c      
-      iparam(1) = ishfts 
-      iparam(3) = maxitr 
-      iparam(7) = mode 
+c
+      iparam(1) = ishfts
+      iparam(3) = maxitr
+      iparam(7) = mode
 c
 c     %-------------------------------------------%
 c     | M A I N   L O O P (Reverse communication) |
@@ -224,13 +233,13 @@ c
  10   continue
 c
 c        %---------------------------------------------%
-c        | Repeatedly call the routine PSSAUPD and take| 
+c        | Repeatedly call the routine PSSAUPD and take|
 c        | actions indicated by parameter IDO until    |
 c        | either convergence is indicated or maxitr   |
 c        | has been exceeded.                          |
 c        %---------------------------------------------%
 c
-         call pssaupd ( comm, ido, bmat, nloc, which, nev, tol, resid, 
+         call pssaupd ( comm, ido, bmat, nloc, which, nev, tol, resid,
      &                 ncv, v, ldv, iparam, ipntr, workd, workl,
      &                 lworkl, info )
 c
@@ -246,7 +255,7 @@ c           | the input, and return the result to  |
 c           | workd(ipntr(2)).                     |
 c           %--------------------------------------%
 c
-            call av ( comm, nloc, nx, mv_buf, 
+            call av ( comm, nloc, nx, mv_buf,
      &               workd(ipntr(1)), workd(ipntr(2)))
 c
 c           %-----------------------------------------%
@@ -255,7 +264,7 @@ c           %-----------------------------------------%
 c
             go to 10
 c
-         end if 
+         end if
 c
 c     %----------------------------------------%
 c     | Either we have convergence or there is |
@@ -276,24 +285,24 @@ c
             print *, ' '
          endif
 c
-      else 
+      else
 c
 c        %-------------------------------------------%
 c        | No fatal errors occurred.                 |
 c        | Post-Process using PSSEUPD.               |
 c        |                                           |
-c        | Computed eigenvalues may be extracted.    |  
+c        | Computed eigenvalues may be extracted.    |
 c        |                                           |
 c        | Eigenvectors may also be computed now if  |
-c        | desired.  (indicated by rvec = .true.)    | 
+c        | desired.  (indicated by rvec = .true.)    |
 c        %-------------------------------------------%
-c           
+c
          rvec = .true.
 c
-         call psseupd ( comm, rvec, 'All', select, 
-     &        d, v, ldv, sigma, 
-     &        bmat, nloc, which, nev, tol, resid, ncv, v, ldv, 
-     &        iparam, ipntr, workd, workl, lworkl, ierr )
+         call psseupd ( comm, rvec, 'All', select,
+     &        d, v, ldv, sigma,
+     &        bmat, nloc, which, nev, tol, resid, ncv, v, ldv,
+     &        iparam, ipntr, workd, workl, lworkl, info )
 c        %----------------------------------------------%
 c        | Eigenvalues are returned in the first column |
 c        | of the two dimensional array D and the       |
@@ -305,7 +314,7 @@ c        | corresponding to the eigenvalues in D is     |
 c        | returned in V.                               |
 c        %----------------------------------------------%
 c
-         if ( ierr .ne. 0) then
+         if ( info .ne. 0) then
 c
 c            %------------------------------------%
 c            | Error condition:                   |
@@ -315,7 +324,7 @@ c
 c
             if ( myid .eq. 0 ) then
              	print *, ' '
-             	print *, ' Error with _seupd, info = ', ierr
+             	print *, ' Error with _seupd, info = ', info
              	print *, ' Check the documentation of _seupd. '
              	print *, ' '
             endif
@@ -362,11 +371,11 @@ c
             print *, ' Maximum number of iterations reached.'
             print *, ' '
          else if ( info .eq. 3) then
-            print *, ' ' 
+            print *, ' '
             print *, ' No shifts could be applied during implicit
      &                 Arnoldi update, try increasing NCV.'
             print *, ' '
-         end if      
+         end if
 c
          print *, ' '
          print *, '_SDRV1 '
@@ -378,8 +387,8 @@ c
          print *, ' The number of Arnoldi vectors generated',
      &            ' (NCV) is ', ncv
          print *, ' What portion of the spectrum: ', which
-         print *, ' The number of converged Ritz values is ', 
-     &              nconv 
+         print *, ' The number of converged Ritz values is ',
+     &              nconv
          print *, ' The number of Implicit Arnoldi update',
      &            ' iterations taken is ', iparam(3)
          print *, ' The number of OP*x is ', iparam(9)
@@ -398,7 +407,7 @@ c
       call MPI_FINALIZE(rc)
 c
       end
-c 
+c
 c ------------------------------------------------------------------
 c     parallel matrix vector subroutine
 c
@@ -421,14 +430,14 @@ c
 c
 c     .. MPI Declarations ...
       include           'mpif.h'
-      integer           comm, nprocs, myid, ierr,
+      integer*4         comm, nprocs, myid, ierr,
      &                  status(MPI_STATUS_SIZE)
       integer           nloc, nx, np, j, lo, next, prev
       Real
      &                  v(nloc), w(nloc), mv_buf(nx), one
       parameter         (one = 1.0 )
       external          saxpy
- 
+
       call MPI_COMM_RANK( comm, myid, ierr )
       call MPI_COMM_SIZE( comm, nprocs, ierr )
 c
@@ -478,7 +487,7 @@ c
 c=========================================================================
       subroutine tv (nx, x, y)
 c
-      integer           nx, j 
+      integer           nx, j
       Real
      &                  x(nx), y(nx), dd, dl, du
 c
@@ -487,18 +496,18 @@ c
       parameter        (one = 1.0 )
 c
 c     Compute the matrix vector multiplication y<---T*x
-c     where T is a nx by nx tridiagonal matrix with DD on the 
+c     where T is a nx by nx tridiagonal matrix with DD on the
 c     diagonal, DL on the subdiagonal, and DU on the superdiagonal.
-c     
+c
 c
       dd  = 4.0
-      dl  = -one 
+      dl  = -one
       du  = -one
-c 
+c
       y(1) =  dd*x(1) + du*x(2)
       do 10 j = 2,nx-1
-         y(j) = dl*x(j-1) + dd*x(j) + du*x(j+1) 
- 10   continue 
-      y(nx) =  dl*x(nx-1) + dd*x(nx) 
+         y(j) = dl*x(j-1) + dd*x(j) + du*x(j+1)
+ 10   continue
+      y(nx) =  dl*x(nx-1) + dd*x(nx)
       return
       end
