@@ -4,8 +4,8 @@ c\Name: pcnaitr
 c
 c Message Passing Layer: BLACS
 c
-c\Description: 
-c  Reverse communication interface for applying NP additional steps to 
+c\Description:
+c  Reverse communication interface for applying NP additional steps to
 c  a K step nonsymmetric Arnoldi factorization.
 c
 c  Input:  OP*V_{k}  -  V_{k}*H = r_{k}*e_{k}^T
@@ -21,7 +21,7 @@ c  computed and returned.
 c
 c\Usage:
 c  call pcnaitr
-c     ( COMM, IDO, BMAT, N, K, NP, NB, RESID, RNORM, V, LDV, H, LDH, 
+c     ( COMM, IDO, BMAT, N, K, NP, NB, RESID, RNORM, V, LDV, H, LDH,
 c       IPNTR, WORKD, WORKL, INFO )
 c
 c\Arguments
@@ -65,8 +65,8 @@ c  NP      Integer.  (INPUT)
 c          Number of additional Arnoldi steps to take.
 c
 c  NB      Integer.  (INPUT)
-c          Blocksize to be used in the recurrence.          
-c          Only work for NB = 1 right now.  The goal is to have a 
+c          Blocksize to be used in the recurrence.
+c          Only work for NB = 1 right now.  The goal is to have a
 c          program that implement both the block and non-block method.
 c
 c  RESID   Complex array of length N.  (INPUT/OUTPUT)
@@ -78,37 +78,37 @@ c          B-norm of the starting residual on input.
 c          B-norm of the updated residual r_{k+p} on output.
 c
 c  V       Complex N by K+NP array.  (INPUT/OUTPUT)
-c          On INPUT:  V contains the Arnoldi vectors in the first K 
+c          On INPUT:  V contains the Arnoldi vectors in the first K
 c          columns.
 c          On OUTPUT: V contains the new NP Arnoldi vectors in the next
 c          NP columns.  The first K columns are unchanged.
 c
 c  LDV     Integer.  (INPUT)
-c          Leading dimension of V exactly as declared in the calling 
+c          Leading dimension of V exactly as declared in the calling
 c          program.
 c
 c  H       Complex (K+NP) by (K+NP) array.  (INPUT/OUTPUT)
 c          H is used to store the generated upper Hessenberg matrix.
 c
 c  LDH     Integer.  (INPUT)
-c          Leading dimension of H exactly as declared in the calling 
+c          Leading dimension of H exactly as declared in the calling
 c          program.
 c
 c  IPNTR   Integer array of length 3.  (OUTPUT)
-c          Pointer to mark the starting locations in the WORK for 
+c          Pointer to mark the starting locations in the WORK for
 c          vectors used by the Arnoldi iteration.
 c          -------------------------------------------------------------
 c          IPNTR(1): pointer to the current operand vector X.
 c          IPNTR(2): pointer to the current result vector Y.
-c          IPNTR(3): pointer to the vector B * X when used in the 
+c          IPNTR(3): pointer to the vector B * X when used in the
 c                    shift-and-invert mode.  X is the current operand.
 c          -------------------------------------------------------------
-c          
+c
 c  WORKD   Complex work array of length 3*N.  (REVERSE COMMUNICATION)
 c          Distributed array to be used in the basic Arnoldi iteration
-c          for reverse communication.  The calling program should not 
+c          for reverse communication.  The calling program should not
 c          use WORKD as temporary workspace during the iteration !!!!!!
-c          On input, WORKD(1:N) = B*RESID and is used to save some 
+c          On input, WORKD(1:N) = B*RESID and is used to save some
 c          computation at the first step.
 c
 c  WORKL   Complex work space used for Gram Schmidt orthogonalization
@@ -130,7 +130,7 @@ c\References:
 c  1. D.C. Sorensen, "Implicit Application of Polynomial Filters in
 c     a k-Step Arnoldi Method", SIAM J. Matr. Anal. Apps., 13 (1992),
 c     pp 357-385.
-c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly 
+c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly
 c     Restarted Arnoldi Iteration", Rice University Technical Report
 c     TR95-13, Department of Computational and Applied Mathematics.
 c
@@ -149,21 +149,21 @@ c     slapy2    LAPACK routine to compute sqrt(x**2+y**2) carefully.
 c     cgemv     Level 2 BLAS routine for matrix vector multiplication.
 c     caxpy     Level 1 BLAS that computes a vector triad.
 c     ccopy     Level 1 BLAS that copies one vector to another .
-c     cdotc     Level 1 BLAS that computes the scalar product of 
-c               two vectors. 
+c     cdotc     Level 1 BLAS that computes the scalar product of
+c               two vectors.
 c     cscal     Level 1 BLAS that scales a vector.
 c     csscal    Level 1 BLAS that scales a complex vector by a real number.
-c     pscnorm2  Parallel version of Level 1 BLAS that computes the 
+c     pscnorm2  Parallel version of Level 1 BLAS that computes the
 c               norm of a vector.
 c
 c\Author
 c     Danny Sorensen               Phuong Vu
 c     Richard Lehoucq              CRPC / Rice University
-c     Dept. of Computational &     Houston, Texas 
-c     Applied Mathematics 
-c     Rice University           
-c     Houston, Texas 
-c 
+c     Dept. of Computational &     Houston, Texas
+c     Applied Mathematics
+c     Rice University
+c     Houston, Texas
+c
 c\Parallel Modifications
 c     Kristi Maschhoff
 c
@@ -175,11 +175,11 @@ c FILE: naitr.F   SID: 1.3   DATE OF SID: 3/19/97
 c
 c\Remarks
 c  The algorithm implemented is:
-c  
+c
 c  restart = .false.
-c  Given V_{k} = [v_{1}, ..., v_{k}], r_{k}; 
+c  Given V_{k} = [v_{1}, ..., v_{k}], r_{k};
 c  r_{k} contains the initial residual vector even for k = 0;
-c  Also assume that rnorm = || B*r_{k} || and B*r_{k} are already 
+c  Also assume that rnorm = || B*r_{k} || and B*r_{k} are already
 c  computed by the calling program.
 c
 c  betaj = rnorm ; p_{k+1} = B*r_{k} ;
@@ -187,7 +187,7 @@ c  For  j = k+1, ..., k+np  Do
 c     1) if ( betaj < tol ) stop or restart depending on j.
 c        ( At present tol is zero )
 c        if ( restart ) generate a new starting vector.
-c     2) v_{j} = r(j-1)/betaj;  V_{j} = [V_{j-1}, v_{j}];  
+c     2) v_{j} = r(j-1)/betaj;  V_{j} = [V_{j-1}, v_{j}];
 c        p_{j} = p_{j}/betaj
 c     3) r_{j} = OP*v_{j} where OP is defined as in pcnaupd
 c        For shift-invert mode p_{j} = B*v_{j} is already available.
@@ -202,7 +202,7 @@ c        If (rnorm > 0.717*wnorm) accept step and go back to 1)
 c     5) Re-orthogonalization step:
 c        s = V_{j}'*B*r_{j}
 c        r_{j} = r_{j} - V_{j}*s;  rnorm1 = || r_{j} ||
-c        alphaj = alphaj + s_{j};   
+c        alphaj = alphaj + s_{j};
 c     6) Iterative refinement step:
 c        If (rnorm1 > 0.717*rnorm) then
 c           rnorm = rnorm1
@@ -212,7 +212,7 @@ c           rnorm = rnorm1
 c           If this is the first time in step 6), go to 5)
 c           Else r_{j} lies in the span of V_{j} numerically.
 c              Set r_{j} = 0 and rnorm = 0; go to 1)
-c        EndIf 
+c        EndIf
 c  End Do
 c
 c\EndLib
@@ -220,7 +220,7 @@ c
 c-----------------------------------------------------------------------
 c
       subroutine pcnaitr
-     &   (comm, ido, bmat, n, k, np, nb, resid, rnorm, v, ldv, h, ldh, 
+     &   (comm, ido, bmat, n, k, np, nb, resid, rnorm, v, ldv, h, ldh,
      &    ipntr, workd, workl, info)
 c
 c
@@ -295,7 +295,7 @@ c     %----------------------%
 c     | External Subroutines |
 c     %----------------------%
 c
-      external   caxpy, ccopy, cscal, cgemv, pcgetv0, slabad, 
+      external   caxpy, ccopy, cscal, cgemv, pcgetv0, slabad,
      &           csscal, pcvout, pcmout, pivout, arscnd
 c
 c     %--------------------%
@@ -303,8 +303,8 @@ c     | External Functions |
 c     %--------------------%
 c
       Complex
-     &           cdotc 
-      Real            
+     &           cdotc
+      Real
      &           pslamch, pscnorm2, clanhs, slapy2
       external   cdotc, pscnorm2, clanhs, pslamch, slapy2
 c
@@ -312,7 +312,7 @@ c     %---------------------%
 c     | Intrinsic Functions |
 c     %---------------------%
 c
-      intrinsic  aimag, real, max, sqrt 
+      intrinsic  aimag, real, max, sqrt
 c
 c     %-----------------%
 c     | Data statements |
@@ -343,7 +343,7 @@ c
       end if
 c
       if (ido .eq. 0) then
-c 
+c
 c        %-------------------------------%
 c        | Initialize timing statistics  |
 c        | & message level for debugging |
@@ -351,7 +351,7 @@ c        %-------------------------------%
 c
          call arscnd (t0)
          msglvl = mcaitr
-c 
+c
 c        %------------------------------%
 c        | Initial call to this routine |
 c        %------------------------------%
@@ -367,7 +367,7 @@ c
          irj    = ipj   + n
          ivj    = irj   + n
       end if
-c 
+c
 c     %-------------------------------------------------%
 c     | When in reverse communication mode one of:      |
 c     | STEP3, STEP4, ORTH1, ORTH2, RSTART              |
@@ -397,16 +397,16 @@ c     |        A R N O L D I     I T E R A T I O N     L O O P       |
 c     |                                                              |
 c     | Note:  B*r_{j-1} is already in WORKD(1:N)=WORKD(IPJ:IPJ+N-1) |
 c     %--------------------------------------------------------------%
- 
+
  1000 continue
 c
          if (msglvl .gt. 1) then
-            call pivout (comm, logfil, 1, j, ndigit, 
+            call pivout (comm, logfil, 1, [j], ndigit,
      &                  '_naitr: generating Arnoldi vector number')
-            call pcvout (comm, logfil, 1, rnorm, ndigit, 
+            call pcvout (comm, logfil, 1, [rnorm], ndigit,
      &                  '_naitr: B-norm of the current residual is')
          end if
-c 
+c
 c        %---------------------------------------------------%
 c        | STEP 1: Check if the B norm of j-th residual      |
 c        | vector is zero. Equivalent to determine whether   |
@@ -423,17 +423,17 @@ c           | basis and continue the iteration.                 |
 c           %---------------------------------------------------%
 c
             if (msglvl .gt. 0) then
-               call pivout (comm, logfil, 1, j, ndigit,
+               call pivout (comm, logfil, 1, [j], ndigit,
      &                     '_naitr: ****** RESTART AT STEP ******')
             end if
-c 
+c
 c           %---------------------------------------------%
 c           | ITRY is the loop variable that controls the |
 c           | maximum amount of times that a restart is   |
 c           | attempted. NRSTRT is used by stat.h         |
 c           %---------------------------------------------%
 c
-            betaj  = rzero 
+            betaj  = rzero
             nrstrt = nrstrt + 1
             itry   = 1
    20       continue
@@ -446,7 +446,7 @@ c           | If in reverse communication mode and |
 c           | RSTART = .true. flow returns here.   |
 c           %--------------------------------------%
 c
-            call pcgetv0 (comm, ido, bmat, itry, .false., n, j, v, ldv, 
+            call pcgetv0 (comm, ido, bmat, itry, .false., n, j, v, ldv,
      &                   resid, rnorm, ipntr, workd, workl, ierr)
             if (ido .ne. 99) go to 9000
             if (ierr .lt. 0) then
@@ -465,7 +465,7 @@ c
                ido = 99
                go to 9000
             end if
-c 
+c
    40    continue
 c
 c        %---------------------------------------------------------%
@@ -506,14 +506,14 @@ c
          ipntr(2) = irj
          ipntr(3) = ipj
          ido = 1
-c 
+c
 c        %-----------------------------------%
 c        | Exit in order to compute OP*v_{j} |
 c        %-----------------------------------%
-c 
-         go to 9000 
+c
+         go to 9000
    50    continue
-c 
+c
 c        %----------------------------------%
 c        | Back from reverse communication; |
 c        | WORKD(IRJ:IRJ+N-1) := OP*v_{j}   |
@@ -522,7 +522,7 @@ c        %----------------------------------%
 c
          call arscnd (t3)
          tmvopx = tmvopx + (t3 - t2)
- 
+
          step3 = .false.
 c
 c        %------------------------------------------%
@@ -530,7 +530,7 @@ c        | Put another copy of OP*v_{j} into RESID. |
 c        %------------------------------------------%
 c
          call ccopy (n, workd(irj), 1, resid, 1)
-c 
+c
 c        %---------------------------------------%
 c        | STEP 4:  Finish extending the Arnoldi |
 c        |          factorization to length j.   |
@@ -543,17 +543,17 @@ c
             ipntr(1) = irj
             ipntr(2) = ipj
             ido = 2
-c 
+c
 c           %-------------------------------------%
 c           | Exit in order to compute B*OP*v_{j} |
 c           %-------------------------------------%
-c 
+c
             go to 9000
          else if (bmat .eq. 'I') then
             call ccopy (n, resid, 1, workd(ipj), 1)
          end if
    60    continue
-c 
+c
 c        %----------------------------------%
 c        | Back from reverse communication; |
 c        | WORKD(IPJ:IPJ+N-1) := B*OP*v_{j} |
@@ -564,7 +564,7 @@ c
             call arscnd (t3)
             tmvbx = tmvbx + (t3 - t2)
          end if
-c 
+c
          step4 = .false.
 c
 c        %-------------------------------------%
@@ -600,7 +600,7 @@ c
 c
 c        %--------------------------------------%
 c        | Orthogonalize r_{j} against V_{j}.   |
-c        | RESID contains OP*v_{j}. See STEP 3. | 
+c        | RESID contains OP*v_{j}. See STEP 3. |
 c        %--------------------------------------%
 c
          call cgemv ('N', n, j, -one, v, ldv, h(1,j), 1,
@@ -609,9 +609,9 @@ c
          if (j .gt. 1) h(j,j-1) = cmplx(betaj, rzero)
 c
          call arscnd (t4)
-c 
+c
          orth1 = .true.
-c 
+c
          call arscnd (t2)
          if (bmat .eq. 'G') then
             nbx = nbx + 1
@@ -619,17 +619,17 @@ c
             ipntr(1) = irj
             ipntr(2) = ipj
             ido = 2
-c 
+c
 c           %----------------------------------%
 c           | Exit in order to compute B*r_{j} |
 c           %----------------------------------%
-c 
+c
             go to 9000
          else if (bmat .eq. 'I') then
             call ccopy (n, resid, 1, workd(ipj), 1)
-         end if 
+         end if
    70    continue
-c 
+c
 c        %---------------------------------------------------%
 c        | Back from reverse communication if ORTH1 = .true. |
 c        | WORKD(IPJ:IPJ+N-1) := B*r_{j}.                    |
@@ -639,7 +639,7 @@ c
             call arscnd (t3)
             tmvbx = tmvbx + (t3 - t2)
          end if
-c 
+c
          orth1 = .false.
 c
 c        %------------------------------%
@@ -653,7 +653,7 @@ c
          else if (bmat .eq. 'I') then
             rnorm = pscnorm2(comm, n, resid, 1)
          end if
-c 
+c
 c        %-----------------------------------------------------------%
 c        | STEP 5: Re-orthogonalization / Iterative refinement phase |
 c        | Maximum NITER_ITREF tries.                                |
@@ -676,20 +676,20 @@ c
 c
          iter  = 0
          nrorth = nrorth + 1
-c 
+c
 c        %---------------------------------------------------%
 c        | Enter the Iterative refinement phase. If further  |
 c        | refinement is necessary, loop back here. The loop |
 c        | variable is ITER. Perform a step of Classical     |
 c        | Gram-Schmidt using all the Arnoldi vectors V_{j}  |
 c        %---------------------------------------------------%
-c 
+c
    80    continue
 c
          if (msglvl .gt. 2) then
             rtemp(1) = wnorm
             rtemp(2) = rnorm
-            call psvout (comm, logfil, 2, rtemp, ndigit, 
+            call psvout (comm, logfil, 2, rtemp, ndigit,
      &      '_naitr: re-orthogonalization; wnorm and rnorm are')
             call pcvout (comm, logfil, j, h(1,j), ndigit,
      &                  '_naitr: j-th column of H')
@@ -711,10 +711,10 @@ c        | The correction to H is v(:,1:J)*H(1:J,1:J)  |
 c        | + v(:,1:J)*WORKD(IRJ:IRJ+J-1)*e'_j.         |
 c        %---------------------------------------------%
 c
-         call cgemv ('N', n, j, -one, v, ldv, workl(1), 1, 
+         call cgemv ('N', n, j, -one, v, ldv, workl(1), 1,
      &               one, resid, 1)
          call caxpy (j, one, workl(1), 1, h(1,j), 1)
-c 
+c
          orth2 = .true.
          call arscnd (t2)
          if (bmat .eq. 'G') then
@@ -723,16 +723,16 @@ c
             ipntr(1) = irj
             ipntr(2) = ipj
             ido = 2
-c 
+c
 c           %-----------------------------------%
 c           | Exit in order to compute B*r_{j}. |
 c           | r_{j} is the corrected residual.  |
 c           %-----------------------------------%
-c 
+c
             go to 9000
          else if (bmat .eq. 'I') then
             call ccopy (n, resid, 1, workd(ipj), 1)
-         end if 
+         end if
    90    continue
 c
 c        %---------------------------------------------------%
@@ -742,12 +742,12 @@ c
          if (bmat .eq. 'G') then
             call arscnd (t3)
             tmvbx = tmvbx + (t3 - t2)
-         end if 
+         end if
 c
 c        %-----------------------------------------------------%
 c        | Compute the B-norm of the corrected residual r_{j}. |
 c        %-----------------------------------------------------%
-c 
+c
          if (bmat .eq. 'G') then
              cnorm = cdotc (n, resid, 1, workd(ipj), 1)
              call cgsum2d( comm, 'All', ' ', 1, 1, cnorm, 1, -1, -1 )
@@ -755,9 +755,9 @@ c
          else if (bmat .eq. 'I') then
              rnorm1 = pscnorm2(comm, n, resid, 1)
          end if
-c 
+c
          if (msglvl .gt. 0 .and. iter .gt. 0 ) then
-            call pivout (comm, logfil, 1, j, ndigit,
+            call pivout (comm, logfil, 1, [j], ndigit,
      &           '_naitr: Iterative refinement for Arnoldi residual')
             if (msglvl .gt. 2) then
                 rtemp(1) = rnorm
@@ -785,7 +785,7 @@ c           | angle of less than arcCOS(0.717)      |
 c           %---------------------------------------%
 c
             rnorm = rnorm1
-c 
+c
          else
 c
 c           %-------------------------------------------%
@@ -807,21 +807,21 @@ c
   95        continue
             rnorm = rzero
          end if
-c 
+c
 c        %----------------------------------------------%
 c        | Branch here directly if iterative refinement |
 c        | wasn't necessary or after at most NITER_REF  |
 c        | steps of iterative refinement.               |
 c        %----------------------------------------------%
-c 
+c
   100    continue
-c 
+c
          rstart = .false.
          orth2  = .false.
-c 
+c
          call arscnd (t5)
          titref = titref + (t5 - t4)
-c 
+c
 c        %------------------------------------%
 c        | STEP 6: Update  j = j+1;  Continue |
 c        %------------------------------------%
@@ -832,13 +832,13 @@ c
             tcaitr = tcaitr + (t1 - t0)
             ido = 99
             do 110 i = max(1,k), k+np-1
-c     
+c
 c              %--------------------------------------------%
 c              | Check for splitting and deflation.         |
 c              | Use a standard test as in the QR algorithm |
 c              | REFERENCE: LAPACK subroutine clahqr        |
 c              %--------------------------------------------%
-c     
+c
                tst1 = slapy2(real(h(i,i)),aimag(h(i,i)))
      &              + slapy2(real(h(i+1,i+1)), aimag(h(i+1,i+1)))
                if( tst1.eq.real(zero) )
@@ -847,12 +847,12 @@ c
      &                    max( ulp*tst1, smlnum ) )
      &             h(i+1,i) = zero
  110        continue
-c     
+c
             if (msglvl .gt. 2) then
-               call pcmout (comm, logfil, k+np, k+np, h, ldh, ndigit, 
+               call pcmout (comm, logfil, k+np, k+np, h, ldh, ndigit,
      &          '_naitr: Final upper Hessenberg matrix H of order K+NP')
             end if
-c     
+c
             go to 9000
          end if
 c
@@ -861,7 +861,7 @@ c        | Loop back to extend the factorization by another step. |
 c        %--------------------------------------------------------%
 c
       go to 1000
-c 
+c
 c     %---------------------------------------------------------------%
 c     |                                                               |
 c     |  E N D     O F     M A I N     I T E R A T I O N     L O O P  |
