@@ -11,15 +11,14 @@
  * with entries 1000, 999, ... , 2, 1 on the diagonal.
  */
 
-#include "parpack.hpp"
-
 #include <array>
 #include <cmath>
 #include <iostream>
 #include <vector>
 
 #include "debug_c.hpp"  // debug parpack.
-#include "stat_c.hpp"   // arpack statistics.
+#include "parpack.hpp"
+#include "stat_c.hpp"  // arpack statistics.
 
 void diagonal_matrix_vector_product(float const* const x, float* const y) {
   for (int i = 0; i < 1000; ++i) {
@@ -35,8 +34,8 @@ void real_symmetric_runner() {
   a_int lworkl = 3 * (ncv * ncv) + 6 * ncv;
   a_int ldv = N;
 
-  bool rvec = true;
-  float tol = 0.0f;
+  a_int rvec = 1;
+  float tol = 0.000001; // small tol => more stable checks after EV computation.
   float sigma = 0.0f;
 
   std::array<a_int, 14> ipntr;
@@ -48,6 +47,7 @@ void real_symmetric_runner() {
   std::vector<float> z((N + 1) * (nev + 1));
   std::vector<float> resid(N);
   std::vector<a_int> select(ncv);
+  for (int i = 0; i < ncv; i++) select[i] = 1;
 
   a_int info = 0;
 
@@ -75,7 +75,10 @@ void real_symmetric_runner() {
                                    &(workd[ipntr[1] - 1]));
   }
   // check number of ev found by arpack.
-  if (iparam[4] != nev || info != 0) {
+  if (iparam[4] < nev /*arpack may succeed to compute more EV than expected*/ ||
+      info != 0) {
+    std::cout << "ERROR: iparam[4] " << iparam[4] << ", nev " << nev
+              << ", info " << info << std::endl;
     throw std::domain_error("Error inside ARPACK routines");
   }
 
@@ -86,8 +89,13 @@ void real_symmetric_runner() {
                 workl.data(), lworkl, info);
 
   for (int i = 0; i < nev; ++i) {
-    std::cout << "rank " << rank << " - " << d[i] << std::endl;
-    if (std::abs(d[i] - static_cast<float>(1000 - (nev - 1) + i)) > 1e-1) {
+    float val = d[i];
+    float ref = (N - (nev - 1) + i);
+    float eps = std::fabs(val - ref);
+    std::cout << "rank " << rank  << " : " << val << " - " << ref << " - " << eps << std::endl;
+
+    /*eigen value order: smallest -> biggest*/
+    if (eps > 1.) {
       throw std::domain_error("Correct eigenvalues not computed");
     }
   }
@@ -107,8 +115,8 @@ void complex_symmetric_runner() {
   a_int ldv = N;
   a_int ldz = N + 1;
 
-  float tol = 0.0f;
-  bool rvec = true;
+  float tol = 0.000001; // small tol => more stable checks after EV computation.
+  a_int rvec = 0;
   std::complex<float> sigma(0.0f, 0.0f);
 
   std::vector<std::complex<float>> resid(N);
@@ -117,6 +125,7 @@ void complex_symmetric_runner() {
   std::vector<std::complex<float>> d(nev + 1);
   std::vector<std::complex<float>> z((N + 1) * (nev + 1));
   std::vector<a_int> select(ncv);
+  for (int i = 0; i < ncv; i++) select[i] = 1;
 
   a_int lworkl = 3 * (ncv * ncv) + 6 * ncv;
   std::vector<std::complex<float>> workl(lworkl);
@@ -153,7 +162,10 @@ void complex_symmetric_runner() {
   }
 
   // check number of ev found by arpack
-  if (iparam[4] != nev || info != 0) {
+  if (iparam[4] < nev /*arpack may succeed to compute more EV than expected*/ ||
+      info != 0) {
+    std::cout << "ERROR: iparam[4] " << iparam[4] << ", nev " << nev
+              << ", info " << info << std::endl;
     throw std::domain_error("Error inside ARPACK routines");
   }
 
@@ -165,10 +177,16 @@ void complex_symmetric_runner() {
                 info);
 
   for (int i = 0; i < nev; ++i) {
-    std::cout << "rank " << rank << " - " << std::real(d[i]) << " "
-              << std::imag(d[i]) << '\n';
-    if (std::abs(std::real(d[i]) - static_cast<float>(1000 - i)) > 1e-1 ||
-        std::abs(std::imag(d[i]) - static_cast<float>(1000 - i)) > 1e-1) {
+    float rval = std::real(d[i]);
+    float rref = (N-(nev-1)+i);
+    float reps = std::fabs(rval - rref);
+    float ival = std::imag(d[i]);
+    float iref = (N-(nev-1)+i);
+    float ieps = std::fabs(ival - iref);
+    std::cout << "rank " << rank << " : " << rval << " " << ival << " - " << rref << " " << iref << " - " << reps << " " << ieps << std::endl;
+
+    /*eigen value order: smallest -> biggest*/
+    if (reps > 1. || ieps > 1.) {
       throw std::domain_error("Correct eigenvalues not computed");
     }
   }
@@ -189,7 +207,7 @@ int main() {
 
   MPI_Barrier(MPI_COMM_WORLD);
 
-  int nopx_c, nbx_c, nrorth_c, nitref_c, nrstrt_c;
+  a_int nopx_c, nbx_c, nrorth_c, nitref_c, nrstrt_c;
   float tsaupd_c, tsaup2_c, tsaitr_c, tseigt_c, tsgets_c, tsapps_c, tsconv_c;
   float tnaupd_c, tnaup2_c, tnaitr_c, tneigt_c, tngets_c, tnapps_c, tnconv_c;
   float tcaupd_c, tcaup2_c, tcaitr_c, tceigt_c, tcgets_c, tcapps_c, tcconv_c;
