@@ -9,25 +9,24 @@
  * matrix with entries 1000, 999, ... , 2, 1 on the diagonal.
  */
 
-#include "arpack.hpp"
-
 #include <array>
 #include <cmath>
 #include <iostream>
 #include <vector>
 
+#include "arpack.hpp"
 #include "debug_c.hpp"  // debug arpack.
 #include "stat_c.hpp"   // arpack statistics.
 
-template<typename Real>
+template <typename Real>
 void diagonal_matrix_vector_product(Real const* const x, Real* const y) {
   for (int i = 0; i < 1000; ++i) {
     y[i] = static_cast<Real>(i + 1) * x[i];
   }
 }
 
-template<typename Real>
-void real_symmetric_runner() {
+template <typename Real>
+void real_symmetric_runner(double const& tol_check) {
   a_int const N = 1000;
   a_int const nev = 9;
 
@@ -38,10 +37,10 @@ void real_symmetric_runner() {
 
   a_int const lworkl = 3 * (ncv * ncv) + 6 * ncv;
 
-  Real const tol = 0.0;
+  Real const tol = 0.000001; // small tol => more stable checks after EV computation.
   Real const sigma = 0.0;
 
-  bool const rvec = true;
+  a_int const rvec = 1;
 
   std::vector<Real> resid(N);
   std::vector<Real> V(ncv * N);
@@ -73,11 +72,14 @@ void real_symmetric_runner() {
   }
 
   // check number of ev found by arpack.
-  if (iparam[4] != nev || info != 0) {
+  if (iparam[4] < nev) { /*arpack may succeed to compute more EV than expected*/
+    std::cout << "ERROR: iparam[4] " << iparam[4] << ", nev " << nev
+              << ", info " << info << std::endl;
     throw std::domain_error("Error inside ARPACK routines");
   }
 
   std::vector<a_int> select(ncv);
+  for (int i = 0; i < ncv; i++) select[i] = 1;
 
   arpack::seupd(rvec, arpack::howmny::ritz_vectors, select.data(), d.data(),
                 z.data(), ldz, sigma, arpack::bmat::identity, N,
@@ -86,16 +88,20 @@ void real_symmetric_runner() {
                 workl.data(), lworkl, info);
 
   for (int i = 0; i < nev; ++i) {
-    std::cout << d[i] << "\n";
+    Real val = d[i];
+    Real ref = static_cast<Real>(N - (nev - 1) + i);
+    Real eps = std::fabs(val - ref);
+    std::cout << val << " - " << ref << " - " << eps << std::endl;
 
-    if (std::abs(d[i] - static_cast<Real>(1000 - (nev - 1) + i)) > 1e-1) {
+    /*eigen value order: smallest -> biggest*/
+    if (eps > tol_check) {
       throw std::domain_error("Correct eigenvalues not computed");
     }
   }
   std::cout << "------\n";
 }
 
-template<typename Real>
+template <typename Real>
 void diagonal_matrix_vector_product(std::complex<Real> const* const x,
                                     std::complex<Real>* const y) {
   for (int i = 0; i < 1000; ++i) {
@@ -103,8 +109,8 @@ void diagonal_matrix_vector_product(std::complex<Real> const* const x,
   }
 }
 
-template<typename Real>
-void complex_symmetric_runner() {
+template <typename Real>
+void complex_symmetric_runner(double const& tol_check) {
   a_int const N = 1000;
   a_int const nev = 9;
 
@@ -115,10 +121,10 @@ void complex_symmetric_runner() {
 
   a_int const lworkl = 3 * (ncv * ncv) + 6 * ncv;
 
-  Real const tol = 0.0;
+  Real const tol = 0.000001; // small tol => more stable checks after EV computation.
   std::complex<Real> const sigma(0.0, 0.0);
 
-  bool const rvec = true;
+  a_int const rvec = 0;
 
   std::vector<std::complex<Real>> resid(N);
   std::vector<std::complex<Real>> V(ncv * N);
@@ -151,11 +157,14 @@ void complex_symmetric_runner() {
   }
 
   // check number of ev found by arpack.
-  if (iparam[4] != nev || info != 0) {
+  if (iparam[4] < nev) { /*arpack may succeed to compute more EV than expected*/
+    std::cout << "ERROR: iparam[4] " << iparam[4] << ", nev " << nev
+              << ", info " << info << std::endl;
     throw std::domain_error("Error inside ARPACK routines");
   }
 
   std::vector<a_int> select(ncv);
+  for (int i = 0; i < ncv; i++) select[i] = 1;
 
   arpack::neupd(rvec, arpack::howmny::ritz_vectors, select.data(), d.data(),
                 z.data(), ldz, sigma, workev.data(), arpack::bmat::identity, N,
@@ -164,10 +173,16 @@ void complex_symmetric_runner() {
                 workl.data(), lworkl, rwork.data(), info);
 
   for (int i = 0; i < nev; ++i) {
-    std::cout << d[i] << "\n";
+    Real rval = std::real(d[i]);
+    Real rref = static_cast<Real>(N - (nev - 1) + i);
+    Real reps = std::fabs(rval - rref);
+    Real ival = std::imag(d[i]);
+    Real iref = static_cast<Real>(N - (nev - 1) + i);
+    Real ieps = std::fabs(ival - iref);
+    std::cout << rval << " " << ival << " - " << rref << " " << iref << " - " << reps << " " << ieps << std::endl;
 
-    if (std::abs(std::real(d[i]) - static_cast<Real>(1000 - i)) > 1e-1 ||
-        std::abs(std::imag(d[i]) - static_cast<Real>(1000 - i)) > 1e-1) {
+    /*eigen value order: smallest -> biggest*/
+    if (reps > tol_check || ieps > tol_check) {
       throw std::domain_error("Correct eigenvalues not computed");
     }
   }
@@ -177,10 +192,10 @@ int main() {
   sstats_c();
 
   // arpack without debug
-  real_symmetric_runner<float>();
-  real_symmetric_runner<double>();
+  real_symmetric_runner<float>(1.);
+  real_symmetric_runner<double>(1.e-05);
 
-  int nopx_c, nbx_c, nrorth_c, nitref_c, nrstrt_c;
+  a_int nopx_c, nbx_c, nrorth_c, nitref_c, nrstrt_c;
   float tsaupd_c, tsaup2_c, tsaitr_c, tseigt_c, tsgets_c, tsapps_c, tsconv_c;
   float tnaupd_c, tnaup2_c, tnaitr_c, tneigt_c, tngets_c, tnapps_c, tnconv_c;
   float tcaupd_c, tcaup2_c, tcaitr_c, tceigt_c, tcgets_c, tcapps_c, tcconv_c;
@@ -200,8 +215,8 @@ int main() {
           1);
 
   // arpack with debug
-  complex_symmetric_runner<float>();
-  complex_symmetric_runner<double>();
+  complex_symmetric_runner<float>(1.);
+  complex_symmetric_runner<double>(1.e-05);
 
   return 0;
 }
